# -*- coding: utf-8 -*-
u"""
This module implements the classes that deals with quantities objects.

It requires the latex package SIunitx.

..  :copyright: (c) 2015 by Björn Dahlgren.
    :license: MIT, see License for more details.
"""

from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division
from builtins import super
from future import standard_library
standard_library.install_aliases()
from operator import itemgetter

from .base_classes import Command
from .package import Package
from .utils import NoEscape


def _dimensionality_to_siunitx(dim):
    string = u''
    items = dim.items()
    for unit, power in sorted(items, key=itemgetter(1), reverse=True):
        if power < 0:
            substring = ur'\per'
            power = -power
        elif power == 0:
            continue
        else:
            substring = u''
        substring += u'\\' + unit.name
        if power > 1:
            substring += ur'\tothe{' + unicode(power) + u'}'
        string += substring
    return NoEscape(string)


class Quantity(Command):
    u"""A class representing quantities."""

    packages = [Package(u'siunitx')]

    def __init__(self, quantity, **_3to2kwargs):
        if 'format_cb' in _3to2kwargs: format_cb = _3to2kwargs['format_cb']; del _3to2kwargs['format_cb']
        else: format_cb = None
        u"""
        Args
        ----
        quantity: `quantities.quantity.Quantity`
            The quantity that should be displayed
        fmtstr: callable
            A function which formats the number in the quantity. By default
            this uses `numpy.array_str`.
        """
        import numpy as np

        self.quantity = quantity
        self._format_cb = format_cb
        if format_cb is None:
            magnitude_str = np.array_str(quantity.magnitude)
        else:
            magnitude_str = format_cb(quantity.magnitude)
        unit_str = _dimensionality_to_siunitx(quantity.dimensionality)
        super(Quantity, self).__init__(command=u'SI', arguments=(magnitude_str, unit_str))
